bayespy.inference.vmp.nodes.multinomial.MultinomialDistribution.compute_mask_to_parent
======================================================================================

.. currentmodule:: bayespy.inference.vmp.nodes.multinomial

.. automethod:: MultinomialDistribution.compute_mask_to_parent